%bcond_with test
%bcond_with ui
%global majminver $(echo %{version} | sed -E 's/\.[0-9]+$//')

Summary:        Printer Drivers Package
Name:           gutenprint
Version:        5.3.4
Release:        5%{?dist}
License:        GPLv2+
URL:            http://gimp-print.sourceforge.net/
Source0:        http://downloads.sourceforge.net/gimp-print/%{name}-%{version}.tar.xz
Source1:        cups-genppdupdate.py.in
Patch3000:      gutenprint-menu.patch
Patch3001:      gutenprint-postscriptdriver.patch
Patch3002:      gutenprint-yyin.patch
Patch3003:      gutenprint-manpage.patch
Patch3004:      gutenprint-xmlfixes.patch
Patch3005:      gutenprint-libusb-crash.patch


BuildRequires: pkgconfig(libusb-1.0) python3-cups python3-devel sed
BuildRequires: libtiff-devel libtool make pkgconfig
BuildRequires: cups-libs gcc gettext-devel libjpeg-devel libpng-devel
BuildRequires: autoconf automake chrpath cups cups-devel

Requires: %{name}-libs = %{version}-%{release}

%description
Gutenprint is a package of high quality printer drivers for Linux, BSD,
Solaris, IRIX, and other UNIX-alike operating systems.
Gutenprint was formerly called Gimp-Print.

%package libs
Summary:       libgutenprint library

%description libs
This package includes libgutenprint library, necessary to run gutenprint.

%if %{with ui}
%package libs-ui
Summary:       libgutenprintui2 library
Requires:      %{name}-libs = %{version}-%{release}

%description libs-ui
This package includes libgutenprintui2 library, which contains
GTK+ widgets, which may be used for print dialogs etc.
%endif

%package devel
Summary:        Library development files for gutenprint
Requires:       %{name} = %{version}-%{release}
Requires:       gtk3-devel

%description devel
This package contains headers and libraries required to build applications that
uses gutenprint package.

%package cups
Summary:        CUPS drivers for Canon, Epson, HP and compatible printers
Requires:       cups
Requires:       %{name} = %{version}-%{release}
Requires:       python3
Requires:       python3-chardet

%description cups
This package contains native CUPS support for a wide range of Canon,
Epson, HP and compatible printers.

%prep
%autosetup -p1

cp %{SOURCE1} src/cups/cups-genppdupdate.in

sed -i -e 's,^#!/usr/bin/python3,#!%{__python3},' src/cups/cups-genppdupdate.in


%build
sed -i -e 's,^\(TESTS *=.*\) run-weavetest,\1,' test/Makefile.in

%configure --disable-dependency-tracking \
                --without-gimp2 \
		--disable-static \
		--disable-cups-ppds \
		--disable-rpath \
		--enable-samples \
		--enable-escputil \
		--enable-test \
		--enable-cups-1_2-enhancements \
		--enable-simplified-cups-ppds

%make_build

%install
%make_install

mkdir -p %{buildroot}%{_sbindir}

rm -rf %{buildroot}%{_datadir}/gutenprint/doc
rm -f %{buildroot}%{_datadir}/foomatic/kitload.log
rm -rf %{buildroot}%{_libdir}/gutenprint/%{majminver}/modules/*.la
rm -f %{buildroot}%{_sysconfdir}/cups/command.types

%find_lang %{name}
sed 's!%{_datadir}/locale/\([^/]*\)/LC_MESSAGES/gutenprint.mo!%{_datadir}/locale/\1/gutenprint_\1.po!g' %{name}.lang >%{name}-po.lang
rm -f %{name}.lang
%find_lang %{name} --all-name
cat %{name}-po.lang >>%{name}.lang

for file in \
  %{buildroot}%{_sbindir}/cups-genppd.%{majminver} \
  %{buildroot}%{_libdir}/*.so.* \
  %{buildroot}%{_cups_serverbin}/driver/* \
  %{buildroot}%{_cups_serverbin}/filter/* \
  %{buildroot}%{_bindir}/*
do
  chrpath --delete ${file}
done

%{_bindir}/rm -f %{buildroot}%{_bindir}/testpattern


%if %{with test}
%check
make check
%endif


%post cups
%{_sbindir}/cups-genppdupdate >/dev/null 2>&1 || :
%{_bindir}/systemctl restart cups >/dev/null 2>&1 || :
exit 0


%files -f %{name}.lang
%license COPYING
%doc AUTHORS NEWS README doc/FAQ.html doc/gutenprint-users-manual.odt doc/gutenprint-users-manual.pdf
%{_bindir}/escputil
%{_datadir}/%{name}
%{_libdir}/%{name}
%{_mandir}/man1/escputil.1*

%files libs
%{_libdir}/libgutenprint.so.9
%{_libdir}/libgutenprint.so.9.5.0

%if %{with ui}
%files libs-ui
%{_libdir}/libgutenprintui2.so.2
%{_libdir}/libgutenprintui2.so.2.5.0
%endif

%files devel
%doc ChangeLog doc/developer/reference-html doc/developer/gutenprint.pdf
%doc doc/gutenprint doc/gutenprintui2
%{_includedir}/gutenprint/
%if %{with ui}
%{_includedir}/gutenprintui2/
%{_libdir}/pkgconfig/gutenprintui2.pc
%endif
%{_libdir}/*.so
%{_libdir}/pkgconfig/gutenprint.pc
%exclude %{_libdir}/*.la

%files cups
%{_bindir}/cups-calibrate
%{_sbindir}/cups-genppd*
%{_cups_serverbin}/filter/*
%{_cups_serverbin}/driver/*
%{_cups_serverbin}/backend/*
%{_datadir}/cups/calibrate.ppm
%{_datadir}/cups/usb/net.sf.gimp-print.usb-quirks
%{_mandir}/man8/cups-calibrate.8*
%{_mandir}/man8/cups-genppd*8*.gz

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.4-5
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 5.3.4-4
- Rebuilt for libtiff 4.5.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.4-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.3.4-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 22 2023 cunshunxia <cunshunxia@tencent.com> - 5.3.4-1
- initial build
